AdminClientHandle

Type Alias AdminClientHandle 

pub type AdminClientHandle = Arc<Mutex<dyn AdminClientLike + Send>>;
Boxed-dyn admin client handle: tests substitute a fake here without opening a TCP connection, while production code wraps a real AdminClient.

Aliased Type

pub struct AdminClientHandle { /* private fields */ }